@@ -35,3 +35,8 @@ override_template(context=AssociationContentProvider,
                   name='arrow',
                   template='templates/viewlet-arrow.pt',
                   layer=IONFBaseLayer)
+
+override_template(context=AssociationContentProvider,
+                  name='frame-action',
+                  template='templates/viewlet-frame-action.pt',
+                  layer=IONFBaseLayer)
