@@ -28,18 +28,20 @@ from onf_website.features.search.skin import AggregatedSearchResultsRenderer
 from onf_website.features.search.skin.interfaces.filter import FILTER_CONTAINER_ANNOTATION_KEY, ICollectionFilter, \
     IContentTypeFilter, IFilter, IFilterAggregate, IFilterContainer, IFilterContainerTarget, IFilterProcessor, \
     ILocationFilter, ISearchResultsPortletAdvancedFiltersRendererSettings, ITagFilter, ITargetFilter, IThemeFilter
+from onf_website.features.thesaurus import IThesaurusTermFilterInfo
 from onf_website.reference.location.interfaces.department import IDepartmentTable
 from onf_website.skin.public import aside_sticky
+from pyams_content.features.search import ISearchFolder, ISearchFormRequestParams
 from pyams_content.features.search.portlet.interfaces import IAggregatedPortletRenderer, ISearchResultsPortletSettings
 from pyams_default_theme.features.search.portlet import SearchResultsPortletRendererBaseSettings
 from pyams_default_theme.interfaces import ISearchResultsView
 from pyams_form.interfaces.form import IFormContextPermissionChecker
 from pyams_i18n.interfaces import II18n
 from pyams_portal.interfaces import IPortalContext, IPortletRenderer, MANAGE_TEMPLATE_PERMISSION
-from pyams_skin.layer import IPyAMSLayer
+from pyams_skin.layer import IPyAMSLayer, IPyAMSUserLayer
 from pyams_template.template import template_config
 from pyams_thesaurus.interfaces.thesaurus import IThesaurus, IThesaurusExtracts
-from pyams_utils.adapter import ContextAdapter, adapter_config, get_annotation_adapter
+from pyams_utils.adapter import ContextAdapter, ContextRequestAdapter, adapter_config, get_annotation_adapter
 from pyams_utils.container import BTreeOrderedContainer
 from pyams_utils.factory import factory_config
 from pyams_utils.registry import get_utility, query_utility
@@ -130,6 +132,34 @@ def get_filter_aggregate(context, filter_name, field_name):
     return filter_aggregate
 
 
+@adapter_config(name='facet_label',
+                context=(ISearchFolder, IPyAMSUserLayer),
+                provides=ISearchFormRequestParams)
+class SearchFolderFacetLabelRequestParams(ContextRequestAdapter):
+    """Search folder facet label request params"""
+    
+    def get_params(self):
+        for label in self.request.params.getall('facet_label'):
+            yield {
+                'name': 'facet_label',
+                'value': label
+            }
+
+
+@adapter_config(name='facet_type_label',
+                context=(ISearchFolder, IPyAMSUserLayer),
+                provides=ISearchFormRequestParams)
+class EsSearchFolderFacetTypeLabelRequestParams(ContextRequestAdapter):
+    """Search folder facet type label request params"""
+    
+    def get_params(self):
+        for label in self.request.params.getall('facet_type_label'):
+            yield {
+                'name': 'facet_type_label',
+                'value': label
+            }
+
+
 @factory_config(ITagFilter)
 class TagsFilter(Filter):
     """tags filter"""
@@ -214,6 +244,20 @@ def target_filter_aggregate(context):
     return filter_aggregate
 
 
+@adapter_config(name='hearing',
+                context=(ISearchFolder, IPyAMSUserLayer),
+                provides=ISearchFormRequestParams)
+class SearchFormHearingRequestParams(ContextRequestAdapter):
+    """Search form hearing request params"""
+    
+    def get_params(self):
+        for hearing in self.request.params.getall('hearing'):
+            yield {
+                'name': 'hearing',
+                'value': hearing
+            }
+
+
 @factory_config(ILocationFilter)
 class LocationFilter(Filter):
     """Location filter"""
@@ -238,6 +282,20 @@ def location_filter_aggregate(context):
     }
 
 
+@adapter_config(name='location',
+                context=(ISearchFolder, IPyAMSUserLayer),
+                provides=ISearchFormRequestParams)
+class SearchFormLocationRequestParams(ContextRequestAdapter):
+    """Search form location request params"""
+    
+    def get_params(self):
+        for location in self.request.params.getall('location'):
+            yield {
+                'name': 'location',
+                'value': location
+            }
+
+
 #
 # Filters container
 #
@@ -356,10 +414,10 @@ class SearchResultsPortletAdvancedFiltersRenderer(AggregatedSearchResultsRendere
 
 
 SORTING_MODES = {
-    'alphabetical_asc': lambda x: locale.strxfrm(x['label']),
-    'alphabetical_desc': lambda x: locale.strxfrm(x['label']),
-    'count_asc': lambda x: (x['doc_count'], locale.strxfrm(x['label'])),
-    'count_desc': lambda x: (x['doc_count'], locale.strxfrm(x['label']))
+    'alphabetical_asc': lambda x: locale.strxfrm(x['label'] or ''),
+    'alphabetical_desc': lambda x: locale.strxfrm(x['label'] or ''),
+    'count_asc': lambda x: (x['doc_count'], locale.strxfrm(x['label'] or '')),
+    'count_desc': lambda x: (x['doc_count'], locale.strxfrm(x['label'] or ''))
 }
 
 
@@ -369,12 +427,9 @@ def get_sorting_key(sorting_option):
 
 @adapter_config(required=IFilter,
                 provides=IFilterProcessor)
-class BaseFilterProcessor:
+class BaseFilterProcessor(ContextAdapter):
     """Base filter processor"""
 
-    def __init__(self, context):
-        self.context = context
-
     def process(self, request, aggregations, filter_type=None):
         filter_type = filter_type or self.context.filter_type
         current_filters = request.params.getall(filter_type)
@@ -446,9 +501,14 @@ class BaseFilterAggregationProcessor(BaseFilterProcessor):
             tag_id = int(item['key'])
             tag_object = intids.queryObject(tag_id)
             if tag_object:
+                pictogram = None
+                feature_info = IThesaurusTermFilterInfo(tag_object, None)
+                if feature_info is not None:
+                    pictogram = feature_info.get_pictogram()
                 result.append({
-                    'key': tag_object.public_label or tag_object.label,
+                    'key': tag_object.label,
                     'label': tag_object.public_label or tag_object.label,
+                    'pictogram': pictogram,
                     'doc_count': item['doc_count']
                 })
     
